==> cayenne-3.0.2-src.tar.gz: cayenne-3.0.2-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/access/ObjectsFromDataRowsQuery.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.access;

import java.util.List;
import java.util.Map;

import org.apache.cayenne.DataRow;
import org.apache.cayenne.map.DataMap;
import org.apache.cayenne.map.DbEntity;
import org.apache.cayenne.map.EntityResolver;
import org.apache.cayenne.map.ObjEntity;
import org.apache.cayenne.map.Procedure;
import org.apache.cayenne.query.PrefetchTreeNode;
import org.apache.cayenne.query.Query;
import org.apache.cayenne.query.QueryCacheStrategy;
import org.apache.cayenne.query.QueryMetadata;
import org.apache.cayenne.query.QueryRouter;
import org.apache.cayenne.query.SQLAction;
import org.apache.cayenne.query.SQLActionVisitor;
import org.apache.cayenne.reflect.ClassDescriptor;

class ObjectsFromDataRowsQuery implements Query, QueryMetadata {

    private ClassDescriptor descriptor;

    private List<? extends DataRow> dataRows;

    public ObjectsFromDataRowsQuery(ClassDescriptor descriptor,
            List<? extends DataRow> dataRows) {
        super();
        this.descriptor = descriptor;
        this.dataRows = dataRows;
    }

    public ClassDescriptor getDescriptor() {
        return descriptor;
    }

    public List<? extends DataRow> getDataRows() {
        return dataRows;
    }

    public QueryMetadata getMetaData(EntityResolver resolver) {
        return this;
    }

    public void route(QueryRouter router, EntityResolver resolver, Query substitutedQuery) {
    }

    public SQLAction createSQLAction(SQLActionVisitor visitor) {
        return null;
    }

    public String getName() {
        return null;
    }

    public boolean isResolvingInherited() {
        return false;
    }

    public int getFetchStartIndex() {
        return 0;
    }

    public DataMap getDataMap() {
        return null;
    }

    public ClassDescriptor getClassDescriptor() {
        return null;
    }

    public ObjEntity getObjEntity() {
        return null;
    }

    public DbEntity getDbEntity() {
        return null;
    }

    public Procedure getProcedure() {
        return null;
    }

    public QueryCacheStrategy getCacheStrategy() {
        return null;
    }

    public String getCacheKey() {
        return null;
    }

    public String[] getCacheGroups() {
        return null;
    }

    public boolean isFetchingDataRows() {
        return false;
    }

    public boolean isRefreshingObjects() {
        return false;
    }

    public int getPageSize() {
        return 0;
    }

    public int getFetchOffset() {
        return 0;
    }

    public int getFetchLimit() {
        return 0;
    }

    public Query getOrginatingQuery() {
        return null;
    }

    public PrefetchTreeNode getPrefetchTree() {
        return null;
    }

    public Map<String, String> getPathSplitAliases() {
        return null;
    }

    public List<Object> getResultSetMapping() {
        return null;
    }

    public int getStatementFetchSize() {
        return 0;
    }

    public String getCachePolicy() {
        return null;
    }
}

==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/access/ObjectsFromDataRowsQuery.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/
package org.apache.cayenne.access;

import java.util.List;
import java.util.Map;

import org.apache.cayenne.DataRow;
import org.apache.cayenne.configuration.ConfigurationNodeVisitor;
import org.apache.cayenne.map.DataMap;
import org.apache.cayenne.map.DbEntity;
import org.apache.cayenne.map.EntityResolver;
import org.apache.cayenne.map.ObjEntity;
import org.apache.cayenne.map.Procedure;
import org.apache.cayenne.query.PrefetchTreeNode;
import org.apache.cayenne.query.Query;
import org.apache.cayenne.query.QueryCacheStrategy;
import org.apache.cayenne.query.QueryMetadata;
import org.apache.cayenne.query.QueryRouter;
import org.apache.cayenne.query.SQLAction;
import org.apache.cayenne.query.SQLActionVisitor;
import org.apache.cayenne.reflect.ClassDescriptor;

class ObjectsFromDataRowsQuery implements Query, QueryMetadata {

    private ClassDescriptor descriptor;

    private List<? extends DataRow> dataRows;

    public ObjectsFromDataRowsQuery(ClassDescriptor descriptor,
            List<? extends DataRow> dataRows) {
        super();
        this.descriptor = descriptor;
        this.dataRows = dataRows;
    }

    public ClassDescriptor getDescriptor() {
        return descriptor;
    }

    public List<? extends DataRow> getDataRows() {
        return dataRows;
    }

    public <T> T acceptVisitor(ConfigurationNodeVisitor<T> visitor) {
        return visitor.visitQuery(this);
    }

    public QueryMetadata getMetaData(EntityResolver resolver) {
        return this;
    }

    public void route(QueryRouter router, EntityResolver resolver, Query substitutedQuery) {
    }

    public SQLAction createSQLAction(SQLActionVisitor visitor) {
        return null;
    }

    public String getName() {
        return null;
    }

    public DataMap getDataMap() {
        return null;
    }

    public ClassDescriptor getClassDescriptor() {
        return null;
    }

    public ObjEntity getObjEntity() {
        return null;
    }

    public DbEntity getDbEntity() {
        return null;
    }

    public Procedure getProcedure() {
        return null;
    }

    public QueryCacheStrategy getCacheStrategy() {
        return null;
    }

    public String getCacheKey() {
        return null;
    }

    public String[] getCacheGroups() {
        return null;
    }

    public boolean isFetchingDataRows() {
        return false;
    }

    public boolean isRefreshingObjects() {
        return false;
    }

    public int getPageSize() {
        return 0;
    }

    public int getFetchOffset() {
        return 0;
    }

    public int getFetchLimit() {
        return 0;
    }

    public Query getOrginatingQuery() {
        return null;
    }

    public PrefetchTreeNode getPrefetchTree() {
        return null;
    }

    public Map<String, String> getPathSplitAliases() {
        return null;
    }

    public List<Object> getResultSetMapping() {
        return null;
    }

    public int getStatementFetchSize() {
        return 0;
    }
}
